Crate aventurine

Aventurine is a plugin for Topaz. It provides a System for handling events from a Glium/Glutin window. When a window event occurs, Aventurine fires a Universe event.

Check out the EventSystem struct and the empty-window example to get started.

Structs

EventSystem
System for handling window events by converting them into Universe events.
KeyboardInput
Describes a keyboard input event.

Enums

MouseButton
Describes a button of a mouse controller.
WindowEvent
Describes an event from a Window.

Traits

AventurineEvent
The E type passed to topaz::Universe must implement this trait in order to use Aventurine with the Universe.