Aventurine is a plugin for Topaz. It provides
a System for handling events from a Glium/Glutin window. When a window
event occurs, Aventurine fires a Universe event.
Check out the EventSystem struct and the empty-window example to get started.
Structs
- Event
System - System for handling window events by converting them into
Universeevents. - Keyboard
Input - Describes a keyboard input event.
Enums
- Mouse
Button - Describes a button of a mouse controller.
- Window
Event - Describes an event from a
Window.
Traits
- Aventurine
Event - The
Etype passed totopaz::Universemust implement this trait in order to use Aventurine with theUniverse.